@@ -1,7 +1,7 @@
 # ABSTRACT: The base class for Bolts and Spouts.
 
 package IO::Storm::Component;
-$IO::Storm::Component::VERSION = '0.14';
+$IO::Storm::Component::VERSION = '0.15';
 # Imports
 use strict;
 use warnings;
@@ -13,13 +13,15 @@ use JSON::XS;
 use Data::Dumper;
 use IO::Storm::Tuple;
 
-# Setup STDIN/STDOUT/STDERR to use UTF8
-use open qw/:std :utf8/;
-
 # Setup Moo for object-oriented niceties
 use Moo;
 use namespace::clean;
 
+# Setup STDIN/STDOUT/STDERR to use UTF8
+binmode STDERR, ':utf8';
+binmode STDIN,  ':encoding(UTF-8)';
+binmode STDOUT, ':utf8';
+
 has '_pending_commands' => (
     is      => 'rw',
     default => sub { [] },
@@ -163,7 +165,7 @@ sub read_task_ids {
     else {
         my $msg = $self->read_message();
         while ( ref($msg) ne 'ARRAY' ) {
-            push( @{$self->_pending_commands}, $msg );
+            push( @{ $self->_pending_commands }, $msg );
             $msg = $self->read_message();
         }
 
@@ -180,7 +182,7 @@ sub read_command {
     else {
         my $msg = $self->read_message();
         while ( ref($msg) eq 'ARRAY' ) {
-            push( @{$self->_pending_taskids}, $msg );
+            push( @{ $self->_pending_taskids }, $msg );
             $msg = $self->read_message();
         }
         return $msg;
@@ -261,7 +263,7 @@ IO::Storm::Component - The base class for Bolts and Spouts.
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 METHODS
 
